================================
:code:`Trakt['calendars/all/*']`
================================

.. automodule:: trakt.interfaces.calendars

  .. autoclass:: AllCalendarsInterface
    :members: get, new, premieres
    :undoc-members:
